package at.ac.uibk.gitsearch.service;


import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;

import org.codeability.sharing.plugins.api.search.util.ExerciseId;
import org.elasticsearch.node.NodeValidationException;
import org.gitlab4j.api.GitLabApiException;
import org.junit.Assert;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.security.test.context.support.WithMockUser;
import org.springframework.util.StreamUtils;

import at.ac.uibk.gitsearch.GitsearchApp;
import at.ac.uibk.gitsearch.repository.search.testESService.ElasticSearchTestServerConfiguration;

@SpringBootTest(classes = GitsearchApp.class)
@WithMockUser(value = "test", authorities = "sharing")
public class GitLabServiceIT {
	
	@Autowired
	GitlabService gitlabService;
	final String publicGitLabProjectId = "318";
	
	@BeforeAll
	public static void setUpESServer() throws IOException, NodeValidationException {
		ElasticSearchTestServerConfiguration.getTestInstance().startTestNode();
	}

	@Test
	public void testGitLabAccess( ) {
		Assert.assertTrue(gitlabService.repositoryExists(publicGitLabProjectId));
		Assert.assertFalse(gitlabService.repositoryExists("XXXX--keineId--XXX"));
	}

	@Test
	public void testGitLabDownload( ) throws GitLabApiException, IOException {
		final InputStream repositoryZip = gitlabService.getRepositoryZip(publicGitLabProjectId);
		// schwacher Test :-(
		Assert.assertNotNull(repositoryZip);
	}
	
	@Test
	public void getREADMEmd() throws GitLabApiException, IOException {
		final InputStream repositoryFile = gitlabService.getRepositoryFile(new ExerciseId("318", null), "README.md");
		Assert.assertNotNull(repositoryFile);
		
		ByteArrayOutputStream baos = new ByteArrayOutputStream();
		
		StreamUtils.copy(repositoryFile, baos);
		
		Assert.assertTrue("At least 50 characters?", baos.size() > 50); 
	}

}
